@@ -1,10 +1,11 @@
+from django.conf import settings
 from django.contrib.auth.models import Permission, User
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from tree_queries.models import TreeNode
 
 from djgentelella.chunked_upload.models import AbstractChunkedUpload
-from django.conf import settings
+
 
 class GentelellaSettings(models.Model):
     """
@@ -19,8 +20,6 @@ class GentelellaSettings(models.Model):
 
 
 class MenuItem(TreeNode):
-    #name = models.SlugField(max_length=50, unique=True)
-    #parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
     title = models.CharField(max_length=500)
     permission = models.ManyToManyField(Permission, blank=True)
     url_name = models.CharField(max_length=500)
@@ -29,8 +28,10 @@ class MenuItem(TreeNode):
     is_reversed = models.BooleanField(default=False)
     reversed_kwargs = models.CharField(max_length=500, null=True, blank=True,
                                        help_text="Ej key:value,key1:value,key2:value2")
-    reversed_args = models.CharField(max_length=500, null=True, blank=True,
-                                     help_text="Comma separed atributes, can access to template context with request.user.pk")
+    reversed_args = models.CharField(
+        max_length=500, null=True, blank=True,
+        help_text="Comma separed atributes, can access to template context " +
+                  "with request.user.pk")
 
     is_widget = models.BooleanField(default=False)
     icon = models.CharField(max_length=50, null=True, blank=True)
@@ -45,11 +46,12 @@ class MenuItem(TreeNode):
         ordering = ["position"]
         order_insertion_by = ['-id']
 
+
 class Help(models.Model):
     id_view = models.CharField(max_length=50,
                                help_text="View id")
-    question_name = models.CharField(max_length=250,
-                                     help_text="Is a identificaction for question label")
+    question_name = models.CharField(
+        max_length=250, help_text="Is a identificaction for question label")
     help_title = models.CharField(max_length=350, verbose_name=_('Help title'))
     help_text = models.TextField(blank=True, default="", verbose_name=_('Help text'))
 
@@ -58,10 +60,10 @@ class Help(models.Model):
 
 
 class Notification(models.Model):
-    STATE = [('visible',_('Visible')),
-               ('hide', _('Hidden'))]
+    STATE = [('visible', _('Visible')),
+             ('hide', _('Hidden'))]
 
-    MESSAGE_TYPE=(
+    MESSAGE_TYPE = (
         ('default', _('Default')),
         ('info', _('Information')),
         ('success', _('Success')),
@@ -73,8 +75,10 @@ class Notification(models.Model):
     link = models.URLField(verbose_name=_('Link'))
     user = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name=_('User'))
     # warning, success, info,
-    message_type = models.CharField(max_length=150, choices=MESSAGE_TYPE, verbose_name=_('Message Type'))
-    state = models.CharField(max_length=150, default='visible', choices=STATE, verbose_name=_('State'))
+    message_type = models.CharField(max_length=150, choices=MESSAGE_TYPE,
+                                    verbose_name=_('Message Type'))
+    state = models.CharField(max_length=150, default='visible', choices=STATE,
+                             verbose_name=_('State'))
     category = models.UUIDField(null=True, blank=True, verbose_name=_("Category"))
     creation_date = models.DateTimeField(auto_now_add=True)
     update_date = models.DateTimeField(auto_now=True)
@@ -86,22 +90,26 @@ class Notification(models.Model):
         ordering = ['-creation_date']
 
 
-
 class PermissionsCategoryManagement(models.Model):
-
     name = models.CharField(max_length=150, verbose_name=_('Name'))
     category = models.CharField(max_length=50, verbose_name=_('Category'))
     url_name = models.CharField(max_length=50, verbose_name=_('Url Name'))
-    permission = models.ForeignKey(Permission, on_delete=models.CASCADE, null=False, blank=False, verbose_name=_('Permission'))
-
+    permission = models.ForeignKey(Permission, on_delete=models.CASCADE, null=False,
+                                   blank=False, verbose_name=_('Permission'))
 
     def __str__(self):
-        return "%s ½s.%s"%(self.category, self.url_name)
+        return "%s ½s.%s" % (self.category, self.url_name)
+
+    class Meta:
+        permissions = [('can_manage_permissions', 'Can manage permissions')]
 
 
-# determine the "null" and "blank" properties of "user" field in the "ChunkedUpload" model
-DEFAULT_MODEL_USER_FIELD_NULL = getattr(settings, 'CHUNKED_UPLOAD_MODEL_USER_FIELD_NULL', True)
-DEFAULT_MODEL_USER_FIELD_BLANK = getattr(settings, 'CHUNKED_UPLOAD_MODEL_USER_FIELD_BLANK', True)
+# determine the "null" and "blank" properties of "user" field in
+# the "ChunkedUpload" model
+DEFAULT_MODEL_USER_FIELD_NULL = getattr(settings,
+                                        'CHUNKED_UPLOAD_MODEL_USER_FIELD_NULL', True)
+DEFAULT_MODEL_USER_FIELD_BLANK = getattr(settings,
+                                         'CHUNKED_UPLOAD_MODEL_USER_FIELD_BLANK', True)
 
 
 class ChunkedUpload(AbstractChunkedUpload):
