@@ -147,6 +147,9 @@ function createDataTable(id, url, extraoptions={}, addfilter=false, formatDataTa
         colReorder: true,
         responsive: true,
         pagingType: "full_numbers",
+        language: {
+            "url": datatables_lang
+        },
         lengthMenu: [10, 25, 50, 100, 200, 500],
         columns: [
            // {data: "item_sequence", name: "item_sequence", title: "Sequence", type: "string", visible: true},
