@@ -1,7 +1,5 @@
 import json
 
-from django.db.models import QuerySet
-from django.utils.safestring import mark_safe
 from .core import TextInput, update_kwargs
 from ..serializers.calendar import EventSerializer
 
@@ -19,7 +17,8 @@ class CalendarInput(TextInput):
         if extra_attrs is not None:
             if 'required' in extra_attrs:
                 extra_attrs.pop('required')
-        attrs = super(CalendarInput, self).build_attrs(base_attrs, extra_attrs=extra_attrs)
+        attrs = super(CalendarInput, self).build_attrs(base_attrs,
+                                                       extra_attrs=extra_attrs)
         return attrs
 
     def get_context(self, name, value, attrs):
